-file("/opt/homebrew/Cellar/erlang/25.1.1/lib/erlang/lib/parsetools-2.4.1/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(lfe_scan).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 112).
%% Copyright (c) 2008-2020 Robert Virding
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.

%% File    : lfe_scan.erl
%% Author  : Robert Virding
%% Purpose : Token definitions for Lisp Flavoured Erlang.

-export([start_symbol_char/1,symbol_char/1]).

-import(string, [substr/2,substr/3]).

%% start_symbol_char(Char) -> true | false.
%% symbol_char(Char) -> true | false.
%%  Define start symbol chars and symbol chars.

start_symbol_char($#) -> false;
start_symbol_char($`) -> false;
start_symbol_char($') -> false;                 %'
start_symbol_char($,) -> false;
start_symbol_char($|) -> false;                 %Symbol quote character
start_symbol_char(C) -> symbol_char(C).

symbol_char($() -> false;
symbol_char($)) -> false;
symbol_char($[) -> false;
symbol_char($]) -> false;
symbol_char(${) -> false;
symbol_char($}) -> false;
symbol_char($") -> false;
symbol_char($;) -> false;
symbol_char(C) -> ((C > $\s) and (C =< $~)) orelse (C > $\240).

%% symbol_token(Chars, Line) -> {token,{symbol,Line,Symbol}} | {error,E}.
%%  Build a symbol from list of legal characters, else error.

symbol_token(Cs, L) ->
    case catch {ok,list_to_atom(Cs)} of
        {ok,S} -> {token,{symbol,L,S}};
        _ -> {error,"illegal symbol"}
    end.

%% base_token(Chars, Base, Line) -> Integer.
%%  Convert a string of Base characters into a number. We only allow
%%  base betqeen 2 and 36, and an optional sign character first.

base_token(_, B, _) when B < 2; B > 36 ->
    {error,"illegal number base"};
base_token([$+|Cs], B, L) -> base_token(Cs, B, +1, L);
base_token([$-|Cs], B, L) -> base_token(Cs, B, -1, L);
base_token(Cs, B, L) -> base_token(Cs, B, +1, L).

base_token(Cs, B, S, L) ->
    case base_collect(Cs, B, 0) of
        {N,[]} -> {token,{number,L,S*N}};
        {_,_} -> {error,"illegal based number"}
    end.

%% base_collect(Chars, Base, SoFar) -> {Number,RestChars}.
%%  Collect all numeric characters of base Base.

base_collect([C|Cs], Base, SoFar) when C >= $0, C =< $9, C < Base + $0 ->
    Next = SoFar * Base + (C - $0),
    base_collect(Cs, Base, Next);
base_collect([C|Cs], Base, SoFar) when C >= $a, C =< $z, C < Base + $a - 10 ->
    Next = SoFar * Base + (C - $a + 10),
    base_collect(Cs, Base, Next);
base_collect([C|Cs], Base, SoFar) when C >= $A, C =< $Z, C < Base + $A - 10 ->
    Next = SoFar * Base + (C - $A + 10),
    base_collect(Cs, Base, Next);
base_collect([C|Cs], _Base, SoFar) -> {SoFar,[C|Cs]};
base_collect([], _Base, N) -> {N,[]}.

-define(IS_UNICODE(C), ((C >= 0) and (C =< 16#10FFFF))).

%% char_token(InputChars, Line) -> {token,{number,L,N}} | {error,E}.
%%  Convert an input string into the corresponding character. For a
%%  sequence of hex characters we check resultant is code is in the
%%  unicode range.

char_token([$x,C|Cs], L) ->
    case base_collect([C|Cs], 16, 0) of
        {N,[]} when ?IS_UNICODE(N) -> {token,{number,L,N}};
        _ -> {error,"illegal character"}
    end;
char_token([C], L) -> {token,{number,L,C}}.

%% chars(InputChars) -> Chars.
%%  Convert an input string into the corresponding string characters.
%%  We know that the input string is correct.

chars([$\\,$x,C|Cs0]) ->
    case is_hex_char(C) of
        true ->
            case base_collect([C|Cs0], 16, 0) of
                {N,[$;|Cs1]} -> [N|chars(Cs1)];
                _Other -> [escape_char($x)|chars([C|Cs0])]
            end;
        false -> [escape_char($x)|chars([C|Cs0])]
    end;
chars([$\\,C|Cs]) -> [escape_char(C)|chars(Cs)];
chars([C|Cs]) -> [C|chars(Cs)];
chars([]) -> [].

is_hex_char(C) when C >= $0, C =< $9 -> true;
is_hex_char(C) when C >= $a, C =< $f -> true;
is_hex_char(C) when C >= $A, C =< $F -> true;
is_hex_char(_) -> false.

escape_char($b) -> $\b;                %\b = BS
escape_char($t) -> $\t;                %\t = TAB
escape_char($n) -> $\n;                %\n = LF
escape_char($v) -> $\v;                %\v = VT
escape_char($f) -> $\f;                %\f = FF
escape_char($r) -> $\r;                %\r = CR
escape_char($e) -> $\e;                %\e = ESC
escape_char($s) -> $\s;                %\s = SPC
escape_char($d) -> $\d;                %\d = DEL
escape_char(C) -> C.                   %\Other = Other

%% Block Comment:
%%  Provide a sensible error when people attempt to include nested
%%  comments because currently the parser cannot process them without
%%  a rebuild. But simply exploding on a '#|' is not going to be that
%%  helpful.

block_comment(TokenChars) ->
    %% Check we're not opening another comment block.
    case string:str(TokenChars, "#|") of
        0 -> skip_token; %% No nesting found
        _ -> {error, "illegal nested block comment"}
    end.

%% skip_until(String, Char1, Char2) -> String.
%%  Skip characters until we get a C1 or C2.

%% skip_until([C|_]=Cs, C1, C2) when C =:= C1 ; C =:= C2 -> Cs;
%% skip_until([_|Cs], C1, C2) -> skip_until(Cs, C1, C2);
%% skip_until([], _, _) -> [].

%% skip_past(String, Char1, Char2) -> String.
%%  Skip characters until we get a C1 or C2 and then skip past it.

skip_past([C|Cs], C1, C2) when C =:= C1 ; C =:= C2 -> Cs;
skip_past([_|Cs], C1, C2) -> skip_past(Cs, C1, C2);
skip_past([], _, _) -> [].

-file("/opt/homebrew/Cellar/erlang/25.1.1/lib/erlang/lib/parsetools-2.4.1/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transition state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,Tlen,_Ics1,L1,_S1} ->
            Tcs1 = yysuf(Tcs, Alen),
            L2 = adjust_line(Tlen, Alen, Tcs1, L1),
            string_cont(Tcs1, L2, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->       % Use last accept match
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            token_cont(Tcs1, L2, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            tokens_cont(Tcs1, L2, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            skip_cont(Tcs1, L2, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

-compile({nowarn_unused_function, [yyrev/1, yyrev/2, yypre/2, yysuf/2]}).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% adjust_line(TokenLength, AcceptLength, Chars, Line) -> NewLine
%% Make sure that newlines in Chars are not counted twice.
%% Line has been updated with respect to newlines in the prefix of
%% Chars consisting of (TokenLength - AcceptLength) characters.

-compile({nowarn_unused_function, adjust_line/4}).

adjust_line(N, N, _Cs, L) -> L;
adjust_line(T, A, [$\n|Cs], L) ->
    adjust_line(T-1, A, Cs, L-1);
adjust_line(T, A, [_|Cs], L) ->
    adjust_line(T-1, A, Cs, L).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.erl", 463).
yystate() -> 65.

yystate(68, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 58 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,68};
yystate(67, [59|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 30, Tlen);
yystate(67, [10|Ics], Line, Tlen, _, _) ->
    yystate(67, Ics, Line+1, Tlen+1, 30, Tlen);
yystate(67, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(67, Ics, Line, Tlen+1, 30, Tlen);
yystate(67, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(67, Ics, Line, Tlen+1, 30, Tlen);
yystate(67, Ics, Line, Tlen, _, _) ->
    {30,Tlen,Ics,Line,67};
yystate(66, [126|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [124|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [92|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [33|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(66, Ics, Line, Tlen+1, 21, Tlen);
yystate(66, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,66};
yystate(65, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [41|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(67, Ics, Line+1, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(67, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(67, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 38 ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(65, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,65};
yystate(64, [126|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [124|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [92|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [33|Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(64, Ics, Line, Tlen+1, 18, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line,64};
yystate(63, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(63, Ics, Line, Tlen, _, _) ->
    {29,Tlen,Ics,Line,63};
yystate(62, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 58 ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(62, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,62};
yystate(61, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line+1, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 91 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 123 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(61, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,61};
yystate(60, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen+1, Action, Alen);
yystate(60, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,60};
yystate(59, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(59, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(59, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line+1, Tlen+1, Action, Alen);
yystate(59, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(59, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(59, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(59, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(59, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,59};
yystate(58, [126|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [124|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [92|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [33|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(58, Ics, Line, Tlen+1, 20, Tlen);
yystate(58, Ics, Line, Tlen, _, _) ->
    {20,Tlen,Ics,Line,58};
yystate(57, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line};
yystate(56, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line};
yystate(55, Ics, Line, Tlen, _, _) ->
    {22,Tlen,Ics,Line};
yystate(54, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 58 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,54};
yystate(53, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(53, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(53, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 119 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(53, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(53, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,53};
yystate(52, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 38 ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [C|Ics], Line, Tlen, Action, Alen) when C >= 45, C =< 58 ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,52};
yystate(51, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line+1, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(51, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,51};
yystate(50, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line};
yystate(49, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line+1, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 47 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 103, C =< 123 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(49, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,49};
yystate(48, [126|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [124|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [92|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [33|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(48, Ics, Line, Tlen+1, 28, Tlen);
yystate(48, Ics, Line, Tlen, _, _) ->
    {28,Tlen,Ics,Line,48};
yystate(47, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line+1, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(47, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,47};
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(46, Ics, Line, Tlen+1, 15, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(46, Ics, Line, Tlen+1, 15, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(46, Ics, Line, Tlen+1, 15, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line,46};
yystate(45, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line+1, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 47 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 103, C =< 123 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,45};
yystate(44, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 58 ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,44};
yystate(43, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 119 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(43, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,43};
yystate(42, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 119 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(42, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,42};
yystate(41, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line};
yystate(40, [126|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [124|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [92|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [33|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,40};
yystate(39, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line+1, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(39, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,39};
yystate(38, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line};
yystate(37, [59|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 30, Tlen);
yystate(37, [10|Ics], Line, Tlen, _, _) ->
    yystate(67, Ics, Line+1, Tlen+1, 30, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(37, Ics, Line, Tlen+1, 30, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(37, Ics, Line, Tlen+1, 30, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 58 ->
    yystate(37, Ics, Line, Tlen+1, 30, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 60 ->
    yystate(37, Ics, Line, Tlen+1, 30, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {30,Tlen,Ics,Line,37};
yystate(36, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 58 ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(36, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,36};
yystate(35, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line};
yystate(34, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line+1, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 34 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 123 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(34, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,34};
yystate(33, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [47|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [46|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 45 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(33, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 26, Tlen);
yystate(33, Ics, Line, Tlen, _, _) ->
    {26,Tlen,Ics,Line,33};
yystate(32, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line};
yystate(31, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line+1, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(31, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,31};
yystate(30, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line+1, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 123 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(30, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,30};
yystate(29, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(29, Ics, Line, Tlen, _, _) ->
    {29,Tlen,Ics,Line,29};
yystate(28, [126|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [124|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [92|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [33|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(28, Ics, Line, Tlen+1, 17, Tlen);
yystate(28, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line,28};
yystate(27, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line+1, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,27};
yystate(26, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line};
yystate(25, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [101|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [69|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 68 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 100 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(25, Ics, Line, Tlen, _, _) ->
    {27,Tlen,Ics,Line,25};
yystate(24, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line};
yystate(23, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(27, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 119 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(23, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,23};
yystate(22, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line+1, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 34 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 123 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(22, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,22};
yystate(21, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [46|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [47|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [45|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [44|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [43|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [42|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(17, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, Ics, Line, Tlen, _, _) ->
    {29,Tlen,Ics,Line,21};
yystate(20, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [109|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [100|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [98|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [88|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [77|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [68|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [66|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(20, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(20, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,20};
yystate(19, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(11, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 46 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 58 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,19};
yystate(18, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line+1, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 123 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(18, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,18};
yystate(17, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(17, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 27, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {27,Tlen,Ics,Line,17};
yystate(16, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(15, [126|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [124|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [92|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [58|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [47|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [33|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 46 ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(15, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(19, Ics, Line, Tlen+1, 25, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line,15};
yystate(14, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [109|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [101|Ics], Line, Tlen, Action, Alen) ->
    yystate(52, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [100|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [98|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [88|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [77|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [69|Ics], Line, Tlen, Action, Alen) ->
    yystate(52, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [68|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [66|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(7, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(14, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,14};
yystate(13, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(17, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(13, Ics, Line, Tlen, _, _) ->
    {29,Tlen,Ics,Line,13};
yystate(12, [64|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 13, Tlen);
yystate(12, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,12};
yystate(11, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(11, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 46 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(11, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,11};
yystate(10, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(9, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 5, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,9};
yystate(8, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line};
yystate(7, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 38 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [C|Ics], Line, Tlen, Action, Alen) when C >= 45, C =< 58 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(7, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,7};
yystate(6, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line};
yystate(5, [64|Ics], Line, Tlen, _, _) ->
    yystate(1, Ics, Line, Tlen+1, 3, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line,5};
yystate(4, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 39 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [C|Ics], Line, Tlen, Action, Alen) when C >= 42, C =< 58 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [C|Ics], Line, Tlen, Action, Alen) when C >= 94, C =< 122 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [C|Ics], Line, Tlen, Action, Alen) when C >= 160 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,4};
yystate(3, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line};
yystate(2, [126|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [124|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [92|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [58|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [33|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(33, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(63, Ics, Line, Tlen+1, 29, Tlen);
yystate(2, Ics, Line, Tlen, _, _) ->
    {29,Tlen,Ics,Line,2};
yystate(1, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(0, [126|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [124|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [92|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [33|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 160 ->
    yystate(0, Ics, Line, Tlen+1, 16, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, TokenLen, YYtcs, _) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_0(TokenChars);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, _, _, TokenLine) ->
    yyaction_2(TokenLine);
yyaction(3, _, _, TokenLine) ->
    yyaction_3(TokenLine);
yyaction(4, _, _, TokenLine) ->
    yyaction_4(TokenLine);
yyaction(5, _, _, TokenLine) ->
    yyaction_5(TokenLine);
yyaction(6, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_6(TokenChars, TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, _, _, TokenLine) ->
    yyaction_8(TokenLine);
yyaction(9, _, _, TokenLine) ->
    yyaction_9(TokenLine);
yyaction(10, _, _, TokenLine) ->
    yyaction_10(TokenLine);
yyaction(11, _, _, TokenLine) ->
    yyaction_11(TokenLine);
yyaction(12, _, _, TokenLine) ->
    yyaction_12(TokenLine);
yyaction(13, _, _, TokenLine) ->
    yyaction_13(TokenLine);
yyaction(14, _, _, TokenLine) ->
    yyaction_14(TokenLine);
yyaction(15, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_15(TokenChars, TokenLine);
yyaction(16, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_16(TokenChars, TokenLine);
yyaction(17, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_17(TokenChars, TokenLine);
yyaction(18, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_18(TokenChars, TokenLine);
yyaction(19, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_19(TokenChars, TokenLine);
yyaction(20, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_20(TokenChars, TokenLine);
yyaction(21, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_21(TokenChars, TokenLine);
yyaction(22, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_22(TokenChars, TokenLen, TokenLine);
yyaction(23, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_23(TokenChars, TokenLen, TokenLine);
yyaction(24, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_24(TokenChars, TokenLen, TokenLine);
yyaction(25, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_25(TokenChars, TokenLine);
yyaction(26, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_26(TokenChars, TokenLine);
yyaction(27, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_27(TokenChars, TokenLine);
yyaction(28, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_28(TokenChars, TokenLine);
yyaction(29, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_29(TokenChars, TokenLine);
yyaction(30, _, _, _) ->
    yyaction_30();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 34).
yyaction_0(TokenChars) ->
     block_comment (string : substr (TokenChars, 3)) .

-compile({inline,yyaction_1/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 37).
yyaction_1(TokenLine) ->
     { token, { '\'', TokenLine } } .

-compile({inline,yyaction_2/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 38).
yyaction_2(TokenLine) ->
     { token, { '`', TokenLine } } .

-compile({inline,yyaction_3/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 39).
yyaction_3(TokenLine) ->
     { token, { ',', TokenLine } } .

-compile({inline,yyaction_4/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 40).
yyaction_4(TokenLine) ->
     { token, { ',@', TokenLine } } .

-compile({inline,yyaction_5/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 41).
yyaction_5(TokenLine) ->
     { token, { '.', TokenLine } } .

-compile({inline,yyaction_6/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 42).
yyaction_6(TokenChars, TokenLine) ->
     { token, { list_to_atom (TokenChars), TokenLine } } .

-compile({inline,yyaction_7/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 44).
yyaction_7(TokenLine) ->
     { token, { '#B(', TokenLine } } .

-compile({inline,yyaction_8/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 45).
yyaction_8(TokenLine) ->
     { token, { '#M(', TokenLine } } .

-compile({inline,yyaction_9/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 46).
yyaction_9(TokenLine) ->
     { token, { '#(', TokenLine } } .

-compile({inline,yyaction_10/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 47).
yyaction_10(TokenLine) ->
     { token, { '#.', TokenLine } } .

-compile({inline,yyaction_11/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 49).
yyaction_11(TokenLine) ->
     { token, { '#`', TokenLine } } .

-compile({inline,yyaction_12/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 50).
yyaction_12(TokenLine) ->
     { token, { '#;', TokenLine } } .

-compile({inline,yyaction_13/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 51).
yyaction_13(TokenLine) ->
     { token, { '#,', TokenLine } } .

-compile({inline,yyaction_14/1}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 52).
yyaction_14(TokenLine) ->
     { token, { '#,@', TokenLine } } .

-compile({inline,yyaction_15/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 55).
yyaction_15(TokenChars, TokenLine) ->
     char_token (skip_past (TokenChars, 92, 92), TokenLine) .

-compile({inline,yyaction_16/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 58).
yyaction_16(TokenChars, TokenLine) ->
     base_token (skip_past (TokenChars, 42, 42), 2, TokenLine) .

-compile({inline,yyaction_17/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 59).
yyaction_17(TokenChars, TokenLine) ->
     base_token (skip_past (TokenChars, 98, 66), 2, TokenLine) .

-compile({inline,yyaction_18/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 60).
yyaction_18(TokenChars, TokenLine) ->
     base_token (skip_past (TokenChars, 111, 79), 8, TokenLine) .

-compile({inline,yyaction_19/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 61).
yyaction_19(TokenChars, TokenLine) ->
     base_token (skip_past (TokenChars, 100, 68), 10, TokenLine) .

-compile({inline,yyaction_20/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 62).
yyaction_20(TokenChars, TokenLine) ->
     base_token (skip_past (TokenChars, 120, 88), 16, TokenLine) .

-compile({inline,yyaction_21/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 65).
yyaction_21(TokenChars, TokenLine) ->
     { Base, [_ | Ds ] } = base_collect (tl (TokenChars), 10, 0),
     base_token (Ds, Base, TokenLine) .

-compile({inline,yyaction_22/3}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 71).
yyaction_22(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 2, TokenLen - 2),
     { token, { string, TokenLine, chars (S) } } .

-compile({inline,yyaction_23/3}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 76).
yyaction_23(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 3, TokenLen - 3),
     Bin = unicode : characters_to_binary (chars (S), utf8, utf8),
     { token, { binary, TokenLine, Bin } } .

-compile({inline,yyaction_24/3}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 82).
yyaction_24(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 2, TokenLen - 2),
     symbol_token (chars (S), TokenLine) .

-compile({inline,yyaction_25/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 87).
yyaction_25(TokenChars, TokenLine) ->
     FunStr = string : substr (TokenChars, 3),
     { token, { '#\'', TokenLine, FunStr } } .

-compile({inline,yyaction_26/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 91).
yyaction_26(TokenChars, TokenLine) ->
     case catch { ok, list_to_integer (TokenChars) } of
     { ok, I } -> { token, { number, TokenLine, I } } ;
     _ -> { error, "illegal integer" }
     end .

-compile({inline,yyaction_27/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 96).
yyaction_27(TokenChars, TokenLine) ->
     case catch { ok, list_to_float (TokenChars) } of
     { ok, F } -> { token, { number, TokenLine, F } } ;
     _ -> { error, "illegal float" }
     end .

-compile({inline,yyaction_28/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 103).
yyaction_28(TokenChars, TokenLine) ->
     AliasStr = string : substr (TokenChars, 3),
     symbol_token ("Elixir." ++ AliasStr, TokenLine) .

-compile({inline,yyaction_29/2}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 107).
yyaction_29(TokenChars, TokenLine) ->
     symbol_token (TokenChars, TokenLine) .

-compile({inline,yyaction_30/0}).
-file("/Users/oubiwann/lab/lfe/lfe/src/lfe_scan.xrl", 108).
yyaction_30() ->
     skip_token .

-file("/opt/homebrew/Cellar/erlang/25.1.1/lib/erlang/lib/parsetools-2.4.1/include/leexinc.hrl", 313).
